#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-conduit
version:              2.3.8
visibility:           public
id:                   http-conduit-2.3.8-EHVj4SxGcYE5sNggtZCndH
key:                  http-conduit-2.3.8-EHVj4SxGcYE5sNggtZCndH
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/http-conduit
synopsis:
    HTTP client package with conduit interface and HTTPS support.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.

category:             Web, Conduit
abi:                  b1e0defe98d648c67f0729a6d6007109
exposed:              True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple

import-dirs:          /usr/lib/ghc-8.10.5/site-local/http-conduit-2.3.8
library-dirs:         /usr/lib/ghc-8.10.5/site-local/http-conduit-2.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/http-conduit-2.3.8
hs-libraries:         HShttp-conduit-2.3.8-EHVj4SxGcYE5sNggtZCndH
depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ
    attoparsec-0.14.1-CDW2c9fsk3y4jVQKNBcpib base-4.14.2.0
    bytestring-0.10.12.0 conduit-1.3.4.1-GHgRKpknFuqDscwzVojbiE
    conduit-extra-1.3.5-6wbdzvOjyuAGkpGhMnpbur
    http-client-0.7.8-C6JWYZrbeBCPAdb6EpQD6
    http-client-tls-0.3.5.3-1EuJcCGFPgBHafkDNjffQC
    http-types-0.12.3-JSCBEGU6f6MIPS3hXwEPIB mtl-2.2.2
    resourcet-1.2.4.2-7etOfd8fePh2l91avxjTIe transformers-0.5.6.2
    unliftio-core-0.2.0.1-1ibY1oF6Hkc5ZYjZ4yW3Lp

haddock-interfaces:
    /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock

haddock-html:         /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

